==> nextcloud-25.0.8.tgz: nextcloud/apps/photos/l10n/fi.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Julkinen linkki",
    "Photos" : "Kuvat",
    "Your memories under your control" : "Muistosi hallinnassasi",
    "All media" : "Kaikki media",
    "Videos" : "Videot",
    "Albums" : "Albumit",
    "Collaborative albums" : "Yhteiset albumit",
    "People" : "Ihmiset",
    "Folders" : "Kansiot",
    "Favorites" : "Suosikit",
    "On this day" : "Tänä päivänä",
    "Shared with you" : "Jaettu kanssasi",
    "Tags" : "Tunnisteet",
    "Places" : "Sijainnit",
    "Map" : "Kartta",
    "Photos settings" : "Kuvien asetukset",
    "Mark selection as favorite" : "Merkitse valinta suosikeiksi",
    "Add selection to favorites" : "Lisää valinta suosikkeihin",
    "Remove selection from favorites" : "Poista valinta suosikeista",
    "Name of the album" : "Albumin nimi",
    "Location of the album" : "Albumin sijainti",
    "Go back to the previous view." : "Siirry takaisin edelliseen näkymään.",
    "Back" : "Takaisin",
    "Go to the add collaborators view." : "Avaa osanottajien lisäysnäkymä.",
    "Add collaborators" : "Lisää osanottajia",
    "Save." : "Tallenna.",
    "Create the album." : "Luo albumi.",
    "Save" : "Tallenna",
    "Create album" : "Luo albumi",
    "Back to the new album form." : "Takaisin uuden albumin lomakkeeseen.",
    "Add to Album" : "Lisää albumiin",
    "Add selection to album {albumName}" : "Lisää valinta albumiin {albumName}",
    "Shared by" : "Jaettu",
    "Create a new album." : "Luo uusi albumi.",
    "Create new album" : "Luo uusi albumi",
    "New album" : "Uusi albumi",
    "_%n item_::_%n photos and videos_" : ["%n kohde","%n kuvaa ja videota"],
    "Add people or groups who can edit your album" : "Lisää henkilöitä tai ryhmiä, jotka voivat muokata albumia",
    "Search people or groups" : "Etsi käyttäjiä tai ryhmiä",
    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
    "Group" : "Ryhmä",
    "Remove {collaboratorLabel} from the collaborators list" : "Poista {collaboratorLabel} osanottajista",
    "Copy the public link" : "Kopioi julkinen linkki",
    "Public link copied!" : "Julkinen linkki kopioitu!",
    "Copy public link" : "Kopioi julkinen linkki",
    "Delete the public link" : "Poista julkinen linkki",
    "Create public link share" : "Luo julkinen linkkijako",
    "Share via public link" : "Jaa julkisen linkin kautta",
    "Failed to fetch collaborators list." : "Osanottajien haku epäonnistui",
    "Failed to update album." : "Albumin päivittäminen epäonnistui.",
    "This collection does not exist" : "Tätä kokoelmaa ei ole olemassa",
    "An error occurred" : "Tapahtui virhe",
    "_%n photos_::_%n photos_" : ["%n kuva","%n kuvaa"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n määrittämätön kuva","%n määrittämätöntä kuvaa"],
    "Select image {imageName}" : "Valitse kuva {imageName}",
    "The file is in the favorites" : "Tämä tiedosto on suosikeissa",
    "Open the full size \"{name}\" image" : "Avaa kuva \"{name}\" todellisessa koossa",
    "There are no photos or videos yet!" : "Ei kuvia tai videoita vielä!",
    "Add to {destination}" : "Lisää kohteeseen {destination}",
    "Open the \"{name}\" sub-directory" : "Avaa \"{name}\"-alikansio",
    "Back to {folder}" : "Takaisin kansioon {folder}",
    "Share this folder" : "Jaa tämä kansio",
    "_{years} year ago_::_{years} years ago_" : ["{years} vuosi sitten","{years} vuotta sitten"],
    "Enable squared photos view" : "Ota käyttöön neliömäinen kuvanäkymä",
    "Default Photos upload and Albums location" : "Kuvien ja albumien oletusarvoinen lähetyssijainti",
    "Choose default Photos upload and Albums location" : "Valitse kuvien ja albumien oletussijainti",
    "Select the default location for your media" : "Valitse oletussijainti medialle",
    "Invalid location selected" : "Virheellinen sijainti valittu",
    "View" : "Näytä",
    "Photos directory" : "Kuvat-kansio",
    "_%n photo_::_%n photos_" : ["%n kuva","%n kuvaa"],
    "Manage collaborators for this album" : "Hallitse albumin osanottajia",
    "Open actions menu" : "Avaa toimintovalikko",
    "Edit album details" : "Muokkaa albumin tietoja",
    "Download all files in album" : "Lataa kaikki albumin tiedostot",
    "Delete album" : "Poista albumi",
    "Download selected files" : "Lataa valitut tiedostot",
    "Remove selection from album" : "Poista valinta albumista",
    "This album does not have any photos or videos yet!" : "Tässä albumissa ei ole kuvia tai videoita!",
    "Add photos to this album" : "Lisää kuvia tähän albumiin",
    "Manage collaborators" : "Hallitse osanottajia",
    "Save collaborators for this album." : "Tallenna albumin osanottajat.",
    "Cover photo for album {albumName}" : "Kansikuva albumille {albumName}",
    "There is no album yet!" : "Ei vielä albumia!",
    "This person could not be found" : "Tätä henkilöä ei löydy",
    "Rename person" : "Nimeä henkilö uudelleen",
    "Merge with different person" : "Yhdistä toisen henkilön kanssa",
    "Download selected photos" : "Lataa valitut kuvat",
    "Favorite" : "Suosikki",
    "Remove from favorites" : "Poista suosikeista",
    "Remove person" : "Poista henkilö",
    "Name of this person" : "Tämän henkilön nimi",
    "Merge person" : "Yhdistä henkilö",
    "Move to different person" : "Siirrä eri henkilöön",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Siirrä kuva toiselle henkilölle","Siirrä kuvat toiselle henkilölle"],
    "_Remove photo from person_::_Remove photos from person_" : ["Poista kuva henkilöstä","Poista kuvat henkilöstä"],
    "This might take some time depending on the size of your photo library." : "Tämä saattaa kestää hetken riippuen kuvakirjastosi koosta.",
    "Recognized people will show up here" : "Tunnistetut henkilöt näkyvät täällä",
    "This folder does not exist" : "Tätä kansiota ei ole olemassa",
    "Loading folders …" : "Ladataan kansioita…",
    "No photos in here" : "Ei kuvia täällä",
    "This place does not have any photos or videos yet!" : "Tässä sijainnissa ei ole vielä kuvia tai videoita!",
    "Add photos to this place" : "Lisää kuvia tälle sijainnille",
    "Cover photo for place {placeName}" : "Sijainnin {placeName} kansikuva",
    "There is no place yet!" : "Ei sijainteja!",
    "Cover photo for shared album {albumName}." : "Kansikuva jaetulle albumille {albumName}.",
    "Back to tags overview" : "Takaisin tunnistenäkymään",
    "No photos with this tag yet" : "Ei vielä kuvia tällä tunnisteella",
    "No tags yet" : "Ei vielä tunnisteita",
    "Photos with tags will show up here" : "Tunnisteilla varustetut kuvat näkyvät täällä",
    "Popular tags" : "Suositut tunnisteet",
    "Add" : "Lisää",
    "Create a new album" : "Luo uusi albumi",
    "Add selection to an album" : "Lisää valinta albumiin",
    "Add to album" : "Lisää albumiin",
    "Delete selection" : "Poista valinta",
    "No photos or videos in here" : "Ei kuvia tai videoita",
    "Unassigned faces" : "Määrittämättömät kasvot",
    "Failed to fetch collection." : "Kokoelman haku epäonnistui.",
    "Failed to fetch collections list." : "Kokoelmalistan haku epäonnistui.",
    "Failed to fetch faces list." : "Kasvolistauksen noutaminen epäonnistui.",
    "All your media" : "Kaikki media",
    "Album {title}" : "Albumi {title}",
    "Shared Albums" : "Jaetut albumit",
    "Shared album {title}" : "Jaettu albumi {title}",
    "Public album {title}" : "Julkinen albumi {title}",
    "Tagged photos" : "Tunnisteilla varustetut kuvat",
    "Tagged photo {title}" : "Kuvaan {title} asetettu tunniste",
    "{title}'s face" : "Henkilön {title} kasvot",
    "Failed to rename {oldName} to {faceName}." : "Henkilön {oldName} nimeäminen muotoon {faceName} epäonnistui.",
    "Failed to delete {faceName}." : "Henkilön {faceName} poistaminen epäonnistui.",
    "Failed to delete {fileId}." : "Kohteen {fileId} poistaminen epäonnistui.",
    "Failed to delete {fileName}." : "Tiedoston {fileName} poisto epäonnistui.",
    "Failed to set favorite state for {fileId}." : "Suosikkimääritelmän asettaminen kohteelle {fileId} epäonnistui.",
    "Failed to set favorite state for {fileName}." : "Suosikkimääritelmän asettaminen kohteelle {fileName} epäonnistui.",
    "Locations" : "Sijainnit",
    "_Share with %n user_::_Share with %n users_" : ["Jaa %n käyttäjän kanssa","Jaa %n käyttäjän kanssa"],
    "Search for collaborators" : "Etsi osanottajia",
    "Add {collaboratorLabel} to the collaborators list" : "Lisää {collaboratorLabel} osanottajiin",
    "No collaborators available" : "Osanottajia ei löytynyt",
    "Failed to fetch album." : "Albumin noutaminen epäonnistui.",
    "Add photos to the album" : "Lisää kuvia albumiin",
    "Failed to fetch albums list." : "Albumien listan noutaminen epäonnistui.",
    "Shared albums" : "Jaetut albumit",
    "Failed to create {albumName}." : "Albumin {albumName} luominen epäonnistui.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Albumin {currentAlbumName} nimen muuttaminen muotoon {newAlbumName} epäonnistui."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/photos/l10n/fi.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Julkinen linkki",
    "Photos" : "Kuvat",
    "Your memories under your control" : "Muistosi hallinnassasi",
    "All media" : "Kaikki media",
    "Videos" : "Videot",
    "Albums" : "Albumit",
    "Collaborative albums" : "Yhteiset albumit",
    "People" : "Ihmiset",
    "Folders" : "Kansiot",
    "Favorites" : "Suosikit",
    "On this day" : "Tänä päivänä",
    "Shared with you" : "Jaettu kanssasi",
    "Tags" : "Tunnisteet",
    "Places" : "Sijainnit",
    "Map" : "Kartta",
    "Photos settings" : "Kuvien asetukset",
    "Mark selection as favorite" : "Merkitse valinta suosikeiksi",
    "Add selection to favorites" : "Lisää valinta suosikkeihin",
    "Remove selection from favorites" : "Poista valinta suosikeista",
    "Name of the album" : "Albumin nimi",
    "Location of the album" : "Albumin sijainti",
    "Go back to the previous view." : "Siirry takaisin edelliseen näkymään.",
    "Back" : "Takaisin",
    "Go to the add collaborators view." : "Avaa osanottajien lisäysnäkymä.",
    "Add collaborators" : "Lisää osanottajia",
    "Save." : "Tallenna.",
    "Create the album." : "Luo albumi.",
    "Save" : "Tallenna",
    "Create album" : "Luo albumi",
    "Back to the new album form." : "Takaisin uuden albumin lomakkeeseen.",
    "Add to Album" : "Lisää albumiin",
    "Add selection to album {albumName}" : "Lisää valinta albumiin {albumName}",
    "Shared by" : "Jaettu",
    "Create a new album." : "Luo uusi albumi.",
    "Create new album" : "Luo uusi albumi",
    "New album" : "Uusi albumi",
    "_%n item_::_%n photos and videos_" : ["%n kohde","%n kuvaa ja videota"],
    "Add people or groups who can edit your album" : "Lisää henkilöitä tai ryhmiä, jotka voivat muokata albumia",
    "Search people or groups" : "Etsi käyttäjiä tai ryhmiä",
    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
    "Group" : "Ryhmä",
    "Remove {collaboratorLabel} from the collaborators list" : "Poista {collaboratorLabel} osanottajista",
    "Copy the public link" : "Kopioi julkinen linkki",
    "Public link copied!" : "Julkinen linkki kopioitu!",
    "Copy public link" : "Kopioi julkinen linkki",
    "Delete the public link" : "Poista julkinen linkki",
    "Create public link share" : "Luo julkinen linkkijako",
    "Share via public link" : "Jaa julkisen linkin kautta",
    "Failed to fetch collaborators list." : "Osanottajien haku epäonnistui",
    "Failed to update album." : "Albumin päivittäminen epäonnistui.",
    "This collection does not exist" : "Tätä kokoelmaa ei ole olemassa",
    "An error occurred" : "Tapahtui virhe",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n määrittämätön kuva","%n määrittämätöntä kuvaa"],
    "Select image {imageName}" : "Valitse kuva {imageName}",
    "The file is in the favorites" : "Tämä tiedosto on suosikeissa",
    "Open the full size \"{name}\" image" : "Avaa kuva \"{name}\" todellisessa koossa",
    "There are no photos or videos yet!" : "Ei kuvia tai videoita vielä!",
    "Add to {destination}" : "Lisää kohteeseen {destination}",
    "Open the \"{name}\" sub-directory" : "Avaa \"{name}\"-alikansio",
    "Back to {folder}" : "Takaisin kansioon {folder}",
    "Share this folder" : "Jaa tämä kansio",
    "_{years} year ago_::_{years} years ago_" : ["{years} vuosi sitten","{years} vuotta sitten"],
    "Enable squared photos view" : "Ota käyttöön neliömäinen kuvanäkymä",
    "Default Photos upload and Albums location" : "Kuvien ja albumien oletusarvoinen lähetyssijainti",
    "Choose default Photos upload and Albums location" : "Valitse kuvien ja albumien oletussijainti",
    "Select the default location for your media" : "Valitse oletussijainti medialle",
    "Invalid location selected" : "Virheellinen sijainti valittu",
    "View" : "Näytä",
    "Photos directory" : "Kuvat-kansio",
    "_%n photo_::_%n photos_" : ["%n kuva","%n kuvaa"],
    "Unselect all" : "Poista valinnat",
    "Manage collaborators for this album" : "Hallitse albumin osanottajia",
    "Open actions menu" : "Avaa toimintovalikko",
    "Edit album details" : "Muokkaa albumin tietoja",
    "Download all files in album" : "Lataa kaikki albumin tiedostot",
    "Delete album" : "Poista albumi",
    "Download selected files" : "Lataa valitut tiedostot",
    "Remove selection from album" : "Poista valinta albumista",
    "This album does not have any photos or videos yet!" : "Tässä albumissa ei ole kuvia tai videoita!",
    "Add photos to this album" : "Lisää kuvia tähän albumiin",
    "Add photos to {albumName}" : "Lisää kuvia albumiin {albumName}",
    "Manage collaborators" : "Hallitse osanottajia",
    "Save collaborators for this album." : "Tallenna albumin osanottajat.",
    "Cover photo for album {albumName}" : "Kansikuva albumille {albumName}",
    "There is no album yet!" : "Ei vielä albumia!",
    "This person could not be found" : "Tätä henkilöä ei löydy",
    "Rename person" : "Nimeä henkilö uudelleen",
    "Merge with different person" : "Yhdistä toisen henkilön kanssa",
    "Download selected photos" : "Lataa valitut kuvat",
    "Favorite" : "Suosikki",
    "Remove from favorites" : "Poista suosikeista",
    "Remove person" : "Poista henkilö",
    "Name of this person" : "Tämän henkilön nimi",
    "Merge person" : "Yhdistä henkilö",
    "Move to different person" : "Siirrä eri henkilöön",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Siirrä kuva toiselle henkilölle","Siirrä kuvat toiselle henkilölle"],
    "_Remove photo from person_::_Remove photos from person_" : ["Poista kuva henkilöstä","Poista kuvat henkilöstä"],
    "This might take some time depending on the size of your photo library." : "Tämä saattaa kestää hetken riippuen kuvakirjastosi koosta.",
    "Recognized people will show up here" : "Tunnistetut henkilöt näkyvät täällä",
    "This folder does not exist" : "Tätä kansiota ei ole olemassa",
    "Loading folders …" : "Ladataan kansioita…",
    "No photos in here" : "Ei kuvia täällä",
    "This place does not have any photos or videos yet!" : "Tässä sijainnissa ei ole vielä kuvia tai videoita!",
    "Add photos to this place" : "Lisää kuvia tälle sijainnille",
    "Cover photo for place {placeName}" : "Sijainnin {placeName} kansikuva",
    "There is no place yet!" : "Ei sijainteja!",
    "Cover photo for shared album {albumName}." : "Kansikuva jaetulle albumille {albumName}.",
    "Back to tags overview" : "Takaisin tunnistenäkymään",
    "No photos with this tag yet" : "Ei vielä kuvia tällä tunnisteella",
    "No tags yet" : "Ei vielä tunnisteita",
    "Photos with tags will show up here" : "Tunnisteilla varustetut kuvat näkyvät täällä",
    "Popular tags" : "Suositut tunnisteet",
    "Add" : "Lisää",
    "Add to album" : "Lisää albumiin",
    "Delete selection" : "Poista valinta",
    "No photos or videos in here" : "Ei kuvia tai videoita",
    "Unassigned faces" : "Määrittämättömät kasvot",
    "_%n photos_::_%n photos_" : ["%n kuva","%n kuvaa"],
    "Failed to fetch collection." : "Kokoelman haku epäonnistui.",
    "Failed to fetch collections list." : "Kokoelmalistan haku epäonnistui.",
    "Failed to fetch faces list." : "Kasvolistauksen noutaminen epäonnistui.",
    "All your media" : "Kaikki media",
    "Album {title}" : "Albumi {title}",
    "Shared Albums" : "Jaetut albumit",
    "Shared album {title}" : "Jaettu albumi {title}",
    "Public album {title}" : "Julkinen albumi {title}",
    "Tagged photos" : "Tunnisteilla varustetut kuvat",
    "Tagged photo {title}" : "Kuvaan {title} asetettu tunniste",
    "{title}'s face" : "Henkilön {title} kasvot",
    "{startDate} to {endDate}" : "{startDate} - {endDate}",
    "Failed to rename {oldName} to {faceName}." : "Henkilön {oldName} nimeäminen muotoon {faceName} epäonnistui.",
    "Failed to delete {faceName}." : "Henkilön {faceName} poistaminen epäonnistui.",
    "Failed to delete {fileId}." : "Kohteen {fileId} poistaminen epäonnistui.",
    "Failed to delete {fileName}." : "Tiedoston {fileName} poisto epäonnistui.",
    "Failed to set favorite state for {fileId}." : "Suosikkimääritelmän asettaminen kohteelle {fileId} epäonnistui.",
    "Failed to set favorite state for {fileName}." : "Suosikkimääritelmän asettaminen kohteelle {fileName} epäonnistui.",
    "Locations" : "Sijainnit",
    "_Share with %n user_::_Share with %n users_" : ["Jaa %n käyttäjän kanssa","Jaa %n käyttäjän kanssa"],
    "Search for collaborators" : "Etsi osanottajia",
    "Add {collaboratorLabel} to the collaborators list" : "Lisää {collaboratorLabel} osanottajiin",
    "No collaborators available" : "Osanottajia ei löytynyt",
    "Failed to fetch album." : "Albumin noutaminen epäonnistui.",
    "Add photos to the album" : "Lisää kuvia albumiin",
    "Failed to fetch albums list." : "Albumien listan noutaminen epäonnistui.",
    "Shared albums" : "Jaetut albumit",
    "Create a new album" : "Luo uusi albumi",
    "Add selection to an album" : "Lisää valinta albumiin",
    "Failed to create {albumName}." : "Albumin {albumName} luominen epäonnistui.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Albumin {currentAlbumName} nimen muuttaminen muotoon {newAlbumName} epäonnistui."
},
"nplurals=2; plural=(n != 1);");
